Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/keepassxreboot/keepassxc.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/Config.cpp')
-rw-r--r--src/core/Config.cpp9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/core/Config.cpp b/src/core/Config.cpp
index d9c737eb8..03b5e4755 100644
--- a/src/core/Config.cpp
+++ b/src/core/Config.cpp
@@ -68,14 +68,14 @@ Config::Config(QObject* parent)
userPath += QFile::decodeName(env);
}
- userPath += "/keepassx/";
+ userPath += "/keepassxc/";
#else
userPath = QDir::fromNativeSeparators(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
// storageLocation() appends the application name ("/keepassx") to the end
userPath += "/";
#endif
- userPath += "keepassx2.ini";
+ userPath += "keepassxc.ini";
init(userPath);
}
@@ -92,6 +92,7 @@ void Config::init(const QString& fileName)
m_defaults.insert("RememberLastKeyFiles", true);
m_defaults.insert("OpenPreviousDatabasesOnStartup", true);
m_defaults.insert("AutoSaveAfterEveryChange", false);
+ m_defaults.insert("AutoReloadOnChange", true);
m_defaults.insert("AutoSaveOnExit", false);
m_defaults.insert("ShowToolbar", true);
m_defaults.insert("MinimizeOnCopy", false);
@@ -101,6 +102,8 @@ void Config::init(const QString& fileName)
m_defaults.insert("security/clearclipboardtimeout", 10);
m_defaults.insert("security/lockdatabaseidle", false);
m_defaults.insert("security/lockdatabaseidlesec", 10);
+ m_defaults.insert("security/lockdatabaseminimize", false);
+ m_defaults.insert("security/passwordsrepeat", false);
m_defaults.insert("security/passwordscleartext", false);
m_defaults.insert("security/autotypeask", true);
m_defaults.insert("GUI/Language", "system");
@@ -68,14 +68,14 @@ Config::Config(QObject* parent)
#else
userPath = QDir::fromNativeSeparators(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
- // storageLocation() appends the application name ("/keepassx") to the end
+ // storageLocation() appends the application name ("/keepassxc") to the end
userPath += "/";
#endif